@@ -80,30 +80,6 @@ sssp.removeTiddlerCallback = function(context, userParams) {
 	}
 };
 
-// hijack getUserInfo to treat unknown users as anonymous
-var _getUserInfo = tweb.getUserInfo;
-tweb.getUserInfo = function(callback) {
-	_getUserInfo.call(this, function(user) {
-		if(!user.anon) { // double-check whether the user is real
-			$.ajax({
-				url: "%0/users/%1".format([tweb.host, user.name]),
-				type: "GET",
-				success: function(data, status, xhr) {
-					user.anon = false;
-				},
-				error: function(xhr, error, exc) {
-					user.anon = true;
-				},
-				complete: function(xhr, status) {
-					callback(user);
-				}
-			});
-		} else {
-			callback(user);
-		}
-	});
-};
-
 // splits a string once using delimiter
 // mode "l" splits at the first, "r" at the last occurrence
 // returns an object with members type and name
@@ -164,6 +140,21 @@ var plugin = config.extensions.tiddlyspace = {
 			url += ":" + port;
 		}
 		return url;
+	},
+	_disabledTabs: [],
+	disableTab: function(tabTiddler) {
+		if(typeof(tabTiddler) == "string") {
+			plugin._disabledTabs.push(tabTiddler);
+		} else {
+			for(var i = 0; i < tabTiddler.length; i++) {
+				plugin.disableTab(tabTiddler[i]);
+			}
+		}
+	},
+	isDisabledTab: function(tabTitle) {
+		var match = new RegExp("(?:\\[\\[([^\\]]+)\\]\\])", "mg").exec(tabTitle);
+		var tabIdentifier = match ? match[1] : tabTitle;
+		return plugin._disabledTabs.contains(tabIdentifier);
 	}
 };
 
@@ -188,6 +179,26 @@ config.macros.backstageInit = {
 	}
 };
 
+// disable evaluated macro parameters for security reasons
+var _parseParams = String.prototype.parseParams;
+String.prototype.parseParams = function(defaultName, defaultValue, allowEval,
+		noNames, cascadeDefaults) {
+	arguments[2] = false;
+	return _parseParams.apply(this, arguments);
+};
+
+var _tabsMacro = config.macros.tabs.handler;
+config.macros.tabs.handler = function(place, macroName, params) {
+	var newParams = [params[0]]; // keep cookie name
+	for(var i = 1; i < params.length; i += 3) {
+		var tabTitle = params[i + 2];
+		if(!plugin.isDisabledTab(tabTitle)){
+			newParams = newParams.concat(params[i], params[i + 1], tabTitle);
+		}
+	}
+	_tabsMacro.apply(this, [place, macroName, newParams]);
+};
+
 // register style sheet for backstage separately (important)
 store.addNotification("StyleSheetBackstage", refreshStyles);
 
